@@ -11,7 +11,6 @@ accepted by the membership of KDE e.V. (or its successor approved
 by the membership of KDE e.V.), which shall act as a proxy
 defined in Section 14 of version 3 of the license.
 
-
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -23,12 +22,13 @@ along with this program; if not, see http://www.gnu.org/licenses/
 
 #include "twittertimelinewidget.h"
 
-TwitterTimelineWidget::TwitterTimelineWidget(Choqok::Account* account, const QString& timelineName,
-                                             QWidget* parent)
-: TwitterApiTimelineWidget(account, timelineName, parent)
+TwitterTimelineWidget::TwitterTimelineWidget(Choqok::Account *account, const QString &timelineName,
+        QWidget *parent)
+    : TwitterApiTimelineWidget(account, timelineName, parent)
 {
-    if(timelineName.startsWith('@'))
+    if (timelineName.startsWith(QLatin1Char('@'))) {
         setClosable();
+    }
 }
 
 TwitterTimelineWidget::~TwitterTimelineWidget()
