@@ -11,7 +11,6 @@
     by the membership of KDE e.V.), which shall act as a proxy
     defined in Section 14 of version 3 of the license.
 
-
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
@@ -25,26 +24,24 @@
 #ifndef POSTEROUS_H
 #define POSTEROUS_H
 
-#include "plugin.h"
-#include <uploader.h>
+#include "uploader.h"
 
 class KJob;
-class KConfigGroup;
 
 class Posterous : public Choqok::Uploader
 {
     Q_OBJECT
 public:
-    Posterous ( QObject* parent, const QList< QVariant >& args );
+    Posterous(QObject *parent, const QList< QVariant > &args);
     ~Posterous();
 
-    virtual void upload ( const KUrl &localUrl, const QByteArray& medium, const QByteArray& mediumType );
-    QString getAuthToken(const KUrl& localUrl);
-protected slots:
-    void slotUpload ( KJob *job );
+    virtual void upload(const QUrl &localUrl, const QByteArray &medium, const QByteArray &mediumType);
+    QString getAuthToken(const QUrl &localUrl);
+protected Q_SLOTS:
+    void slotUpload(KJob *job);
 
 private:
-    QMap<KJob*, KUrl> mUrlMap;
+    QMap<KJob *, QUrl> mUrlMap;
 };
 
 #endif // POSTEROUS_H
